# external_storage

This contains generic features and snapshot base classes for external snapshot
storage (i.e., storing the snapshot information in a separate trajectory file,
with only a reference to the file/frame number stored in the main OPS storage.)
This is the preferred snapshot mechanism for external (indirect control)
engines.
